<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain

Data Base Write Agent (DBWA) is an intermediate layer which provide access
to the homesite database to perform write, delete, or update queries.
*/

// Recieve functions arguments for the any info or news FUNCTION 
if (isset($_POST['dbwa'])) {$dbwa=$_POST['dbwa'];} else {$dbwa="NULL";}
if (isset($_POST['id_info'])) {$id_info=$_POST['id_info'];} else {$id_info="NULL";}
if (isset($_POST['id_comment'])) {$id_comment=$_POST['id_comment'];} else {$id_comment="NULL";}
if (isset($_POST['id_photo'])) {$id_photo=$_POST['id_photo'];}
if (isset($_POST['edited'])) {$edited=$_POST['edited'];} else {$edited="NULL";}
if (isset($_POST['posted'])) {$posted=$_POST['posted'];} else {$posted="NULL";}

if (!get_magic_quotes_gpc())
   {
   if (isset($_POST['headline'])) {$headline = AddSlashes ($_POST['headline']);} else {$headline="NULL";}
   if (isset($_POST['intro_text'])) {$intro_text=AddSlashes ($_POST['intro_text']);} else {$intro_text="NULL";}
   if (isset($_POST['body_text'])) {$body_text=AddSlashes ($_POST['body_text']);} else {$body_text="NULL";}
   if (isset($_POST['title'])) {$title=AddSlashes ($_POST['title']);} else {$title="NULL";}
   } else {
          if (isset($_POST['headline'])) {$headline=$_POST['headline'];} else {$headline="NULL";}
          if (isset($_POST['intro_text'])) {$intro_text=$_POST['intro_text'];} else {$intro_text="NULL";}
          if (isset($_POST['body_text'])) {$body_text=$_POST['body_text'];} else {$body_text="NULL";}
          if (isset($_POST['title'])) {$title=$_POST['title'];} else {$title="NULL";}
          }

if (isset($_POST['text_type'])) {$text_type=($_POST['text_type']);} else {$text_type="text";}
if (isset($_POST['typed_secret_code'])) {$typed_secret_code=($_POST['typed_secret_code']);} else {$typed_secret_code="text";}
if ($text_type=="text"){$body_text=nl2br($body_text);}

if (isset($_POST['num_photos'])) {$num_photos=$_POST['num_photos'];}
if (isset($_POST['task'])) {$task=$_POST['task'];} // else {$task="NULL";}
if (isset($_POST['choice'])) {$choice=$_POST['choice'];} // else {$task="NULL";}
// Recieve functions arguments for the dbwa_add_user FUNCTION
if (isset($_POST['new_nick'])) {$new_nick=$_POST['new_nick'];} else {$new_nick="NULL";}
if (isset($_POST['password'])) {$password=crypt($_POST['password'],'zzxzv');} else {$password="NULL";}
if (isset($_POST['password_check'])) {$password_check=crypt($_POST['password_check'],'zzxzv');} else {$password_check="NULL";}
if (isset($_POST['email'])) {$email=$_POST['email'];} else {$email="NULL";}

if (!get_magic_quotes_gpc())
   {
   if (isset($_POST['real_name'])) {$real_name=AddSlashes($_POST['real_name']);} else {$real_name="NULL";}
   } elseif (isset($_POST['real_name'])) {$real_name=$_POST['real_name'];} else {$real_name="NULL";}

if (isset($_POST['level'])) {$level=$_POST['level'];} else {$level="NULL";}
// Recieve functions arguments for the dbwa_edit_user and delete FUNCTION
if (isset($_POST['id_user'])) {$id_user=$_POST['id_user'];} else {$id_user="NULL";}
// Recive functions arguments for the dbwa_info FUNCTION
if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab="NULL";}
if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="NULL";}

if (!get_magic_quotes_gpc())
   {
   if (isset($_POST['event_title'])) {$event_title=AddSlashes($_POST['event_title']);} else {$event_title="NULL";}
   if (isset($_POST['event_type'])) {$event_type=AddSlashes($_POST['event_type']);} else {$event_type="NULL";}
   if (isset($_POST['event_place'])) {$event_place=AddSlashes($_POST['event_place']);} else {$event_place="NULL";}
   if (isset($_POST['description'])) {$description=AddSlashes($_POST['description']);} else {$description="NULL";}
   } else {
          if (isset($_POST['event_title'])) {$event_title=$_POST['event_title'];} else {$event_title="NULL";}
          if (isset($_POST['event_type'])) {$event_type=$_POST['event_type'];} else {$event_type="NULL";}
          if (isset($_POST['event_place'])) {$event_place=$_POST['event_place'];} else {$event_place="NULL";}
          if (isset($_POST['description'])) {$description=$_POST['description'];} else {$description="NULL";}
          }

if (isset($_POST['day'])) {$day=$_POST['day'];} else {$day="NULL";}
if (isset($_POST['year'])) {$year=$_POST['year'];} else {$year="NULL";}
if (isset($_POST['month'])) {$month=$_POST['month'];} else {$month="NULL";}
if (isset($_POST['hour'])) {$hour=$_POST['hour'];} else {$hour="NULL";}
if (isset($_POST['minutes'])) {$minutes=$_POST['minutes'];} else {$minutes="NULL";}
// Recieve functions argumnets fot the dbwa_album_* FUNCTIONS
if (isset($_POST['step'])) {$step=$_POST['step'];} else {$step="0";}
if (isset($_POST['id_album'])) {$id_album=$_POST['id_album'];} else {$id_album="lost_album";}
if (isset($_POST['allow_to_see'])) {$allow_to_see=$_POST['allow_to_see'];} else {$allow_to_see="all";}
if (isset($_POST['allow_to_add'])) {$allow_to_add=$_POST['allow_to_add'];} else {$allow_to_add="all";}
if (isset($_POST['allow_to_see_list'])) {$allow_to_see_list=$_POST['allow_to_see_list'];} else {$allow_to_see_list="all";}
if (isset($_POST['allow_to_add_list'])) {$allow_to_add_list=$_POST['allow_to_add_list'];} else {$allow_to_add_list="all";}
if (isset($_POST['id_photo_list'])) {$id_photo_list=$_POST['id_photo_list'];} else {$id_photo_list="NULL";}
if (isset($_POST['filename_list'])) {$filename_list=$_POST['filename_list'];} else {$filename_list="NULL";}
if (isset($_POST['photo_comment_list'])) {$photo_comment_list=$_POST['photo_comment_list'];} else {$photo_comment_list="NULL";}


function check_user_form ($new_nick, $password, $password_check, $n){
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
// If one or more messages are showed, then add initial back returns
if ( $n == 1 || $p == 0 || $l == 0 || $ln == 0) echo "<br><br>";
if ( $n == 0 ) // check for duplicated nicknames
   {
   $n=0;
   } else {
          echo "<div class=\"alert3b\" align=\"center\">$TEXT001</div>";
          $n=1;
          }

if ( $password == $password_check ) // Check for the correct password
   {
   $p=1;
   } else {
          echo "<div class=\"alert3b\" align=\"center\">$TEXT002</div>";
          $p=0;
          }

$p_length=strlen ($password); // Check if the password length is between 8 - 16

if ( $p_length > 7 && $p_length < 17) 
   {
   $l=1;
   } else {
          echo "<div class=\"alert3b\" align=\"center\">$TEXT003</div>";
          $l=0;
          }

$n_length=strlen ($new_nick);

if ( $n_length < 17 ) // Check if the nickname length is between 8 - 16
   {
   $ln=1;
   } else {
          echo "<div class=\"alert3b\" align=\"center\">$TEXT004</div>";
          $ln=0;
          }

// If one or more message are showed, then add final back return  
if ( $n == 1 || $p == 0 || $l == 0 || $ln == 0 )
   {
   echo "<br><div class=\"alert3b\" align=\"center\">$TEXT005</div><br><br>";
   }
if ( $n == 0 && $p == 1 && $l == 1 && $ln == 1 ) { return 0;} else return 1;
}


function dbwa_add_album ($title, $description, $posted, $id_author, $section, $allow_to_see, $allow_to_add, $allow_to_see_list, $allow_to_add_list){
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
include ("config_site.php");
include ("db_connect.php");

$valid_form=1;
if (empty($title))
   {
   echo "<div class=\"alert2b\" align=\"center\"><br>$TEXT006</div>";
   $valid_form=0;
   }
if (($allow_to_see=='list' && $allow_to_see_list['0']=='a') || ($allow_to_add=='list' && $allow_to_add_list['0']=='a'))
   {
   echo "<div class=\"alert2b\" align=\"center\"><br>$TEXT007</div>";
   $valid_form=0;
   }

if (($allow_to_see!='list' && $allow_to_see_list['0']!='a') || ($allow_to_add!='list' && $allow_to_add_list['0']!='a'))
   {
   echo "<div class=\"alert2b\" align=\"center\"><br>$TEXT008</div>";
   $valid_form=0;
   }

if ($valid_form)
   {
   // The default value of attached_photos is 'NO'
   $album_insert=mysql_query ("INSERT INTO album (id_author,title,description,posted,edited,section, allow_to_see, allow_to_add) values ('$id_author','$title','$description','$posted','$posted','$section', '$allow_to_see', '$allow_to_add')");
   $id_album=mysql_insert_id ($db);

   if ($allow_to_see=='list')
      {
      $n=0;
      while($n<count($allow_to_see_list))
           {
           mysql_query ("INSERT INTO album_allow_to_see_list (id_album, id_user)".
                        "values ('$id_album', '$allow_to_see_list[$n]')");
           $n=$n+1;
           }
      }

   if ($allow_to_add=='list')
      {
      $n=0;
      while($n<count($allow_to_add_list))
           {
           mysql_query ("INSERT INTO album_allow_to_add_list (id_album, id_user)".
                        "values ('$id_album', '$allow_to_add_list[$n]')");
           $n=$n+1;
           }
      }
  return 0; // Return ok code
  } else {
         echo "<div class=\"alert3b\" align=\"center\"><br>$TEXT005</div>";
         return 1; // Return Error Code
         }
}


function dbwa_edit_album ($id_album, $title, $description, $posted, $section, $allow_to_see, $allow_to_add, $allow_to_see_list, $allow_to_add_list){
include ("config_site.php");
include ("db_connect.php");

// If the entry already exists, then it only needs to be updated. If not, we need to add a new one.
// The quickest way to do this is rebuild the full list again
mysql_query ("DELETE FROM album_allow_to_see_list WHERE id_album='$id_album'");
mysql_query ("DELETE FROM album_allow_to_add_list WHERE id_album='$id_album'");

// The default value of attached_photos is 'NO'
mysql_query ("UPDATE album SET status='1', title='$title',description='$description',posted='$posted', allow_to_see='$allow_to_see', allow_to_add='$allow_to_add' WHERE id_album='$id_album'");

if ($allow_to_see=='list')
   {
   $n=0;
   while($n<count($allow_to_see_list))
        {
         // If the entry already exists, then it only needs to be updated. If not we need to add a new one.
         // The quickest way to do this is rebuild the full list again
         mysql_query ("INSERT INTO album_allow_to_see_list (id_album, id_user)".
                      "values ('$id_album', '$allow_to_see_list[$n]')");
        $n=$n+1;
        }
   }

if ($allow_to_add=='list')
   {
   $n=0;
   while($n<count($allow_to_add_list))
        {
        // If the entry already exists, then it only needs to be updated. If not we need to add a new one.
        // The quickest way to do this is rebuild the full list again
        mysql_query ("INSERT INTO album_allow_to_add_list (id_album, id_user)".
                     "values ('$id_album', '$allow_to_add_list[$n]')");
        $n=$n+1;
        }
   }

}


function dbwa_add_photo_album ($id_album, $id_author, $description,$posted){
// For each info with photos uploaded, add a new entry in album table, and create the directory
// which contain the photos and thumbnails. If the directory exists, only add the photos and 
// thumbnails inside.

// First of all, we need to know if the file has been correctly uploaded

$userfile_error=$FILES['userfile']['error'];
if ($userfile_error > 0)
   {
   echo 'Error uploading file:';
   switch ($userfile_error)
          {
          case 1: echo 'File is bigger than allowed'; break;
          case 2: echo 'File is bigger than allowed'; break;
          case 3: echo 'File partially uploaded'; break;
          case 4: echo 'No file uploaded'; break;
          }
   exit;
   }

include ("includes/system_config.php");
include ("config_site.php");
include ("db_connect.php");
$exist=file_exists("photos/albums/$id_album");
$is_dir=is_dir("photos/albums/$id_album");
if (!$exist || !$is_dir)mkdir("photos/albums/".$id_album,0777);
if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
   {
   $filename=$_FILES['userfile']['name'][0];
   $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
   $filename=str_replace($pattern,"_",$filename);
   $path_photo="photos/albums/$id_album/$filename";
   move_uploaded_file($_FILES['userfile']['tmp_name'][0], $path_photo);
   $size=getimagesize($path_photo);
   $width=$size[0];
   $height=$size[1];

   // If you have problems generating thumnails, check that the convert tool is installed on your system
   // and the variable CONVERT_PATH match with the path to this tool in your system
   if ( ($height > 1024) || ($width > 1024)  )
       {
       $last_line=system("$CONVERT_PATH -geometry 1024x1024 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/high-$filename",$returned);
       $last_line=system("$CONVERT_PATH -geometry 800x800 +profile \"*\" photos/albums/$id_album/high-$filename photos/albums/$id_album/medium-$filename",$returned);
       $last_line=system("$CONVERT_PATH -geometry 640x640 +profile \"*\" photos/albums/$id_album/medium-$filename photos/albums/$id_album/low-$filename",$returned);
       $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/low-$filename photos/albums/$id_album/thumbnail-$filename",$returned);
       //images bigger than 1024 are not allowed
       unlink ("photos/albums/$id_album/$filename");
       } else if ( ($height > 800) || ($width > 800)  )
                 {
                 $last_line=system("$CONVERT_PATH -geometry 800x800 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/medium-$filename",$returned); 
                 $last_line=system("$CONVERT_PATH -geometry 640x640 +profile \"*\" photos/albums/$id_album/medium-$filename photos/albums/$id_album/low-$filename",$returned); 
                 $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/low-$filename photos/albums/$id_album/thumbnail-$filename",$returned);

                 } else if ( ($height > 640) || ($width > 640)  )
                           {
                           $last_line=system("$CONVERT_PATH -geometry 640x640 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/low-$filename",$returned);
                           $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/low-$filename photos/albums/$id_album/thumbnail-$filename",$returned);
                           } else if ( ($height > 70) || ($width > 70)  )
                                     {
                                     $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/thumbnail-$filename",$returned);
                                     } else copy ( "photos/albums/$id_album/$filename", "photos/albums/$id_album/thumbnail-$filename");

    /*
    Only when the thumbanil image has been generated, the data should be added to the database.
    The reason is to ensure atomic operations. 
    If a problem occurs sending images or generating the different size images, then the thumbnail is not generated.
    When this happens, images which has been sent and can not be found in the database should be removed.
    */

    $thumbnail_exists=file_exists("photos/albums/$id_album/thumbnail-$filename");
    if ($thumbnail_exists)
       {
       mysql_query ("INSERT INTO photo_album (id_album,id_author,description,filename,posted,height,width) values ('$id_album','$id_author','$description','$filename','$posted','$height','$width')"); 
       } else {
              // Lost images should be removed from hard disk
              unlink ("photos/albums/$id_album/$filename");
              unlink ("photos/albums/$id_album/high-$filename");
              unlink ("photos/albums/$id_album/medium-$filename");
              unlink ("photos/albums/$id_album/low-$filename");
              unlink ("photos/albums/$id_album/thumbnail-$filename");
              }

    }

return 0;
}

function dbwa_delete_photo_album ($id_album,$id_photo_list,$filename_list){
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
include ("config_site.php");
include ("db_connect.php");
$n=0;
if ($id_photo_list=="all")
   {
   $sql = "DELETE FROM album WHERE id_album='$id_album'";
   mysql_query($sql, $db);

   $sql = "DELETE FROM photo_album WHERE id_album='$id_album'";
   mysql_query($sql, $db);

   $sql = "DELETE FROM album_allow_to_see_list WHERE id_album='$id_album'";
   mysql_query($sql, $db);

   $sql = "DELETE FROM album_allow_to_add_list WHERE id_album='$id_album'";
   mysql_query($sql, $db);

   $is_dir=is_dir("photos/albums/$id_album");
   $filename="photos/albums/".$id_album;
   echo "<br>";
   foreach (glob("$filename/*") as $file) // Delete all files in the current info folder and shown message about it.
           {
           // Uncoment only for debbuging
           //echo "<span class=\"text1\"><center><b>$file</b> size " . filesize($file) . " has been deleted.</center></span>";
           unlink($file);
           }
   if ($is_dir)
      {
      // Uncoment only for debbuging
      //echo "<span class=\"text1\"><center><br><br>The <b>$filename</b> folder has been deleted</center><br><br>";
      echo "<span class=\"text1\"><center><br>$TEXT009</center><br>";
      rmdir($filename);
      }
   } else foreach ($id_photo_list as $value)
                  {
                  $filename="photos/albums/".$id_album;
                  mysql_query("DELETE FROM photo_album 
                               WHERE id_photo='".$value."' AND id_album='".$id_album."'", $db);
                  echo "<span class=\"text1\"><center>".
                       "<b>$filename_list[$n]</b> $TEXT010 " . filesize("$filename/$filename_list[$n]") .
                       " $TEXT011.</center></span>";
                  unlink("$filename/$filename_list[$n]");
                  unlink("$filename/high-$filename_list[$n]");
                  unlink("$filename/medium-$filename_list[$n]");
                  unlink("$filename/low-$filename_list[$n]");
                  unlink("$filename/thumbnail-$filename_list[$n]");
                  // Uncoment only for debbuging
                  //echo "value-> $value, filename->$filename_list[$n]<br>";
                  $n=$n+1;
                  }
return 0;
}

function dbwa_edit_photo_comments ($id_album,$id_photo_list,$photo_comment_list){
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
include ("config_site.php");
include ("db_connect.php");
$n=0;
foreach ($id_photo_list as $value)
                  {
                  $photo_query=mysql_query("SELECT filename, description
                                           FROM photo_album
                                           WHERE id_photo='".$value."' AND id_album='".$id_album."'", $db);
                  $photo_result=mysql_fetch_array($photo_query);

                  mysql_query ("UPDATE photo_album 
                                SET description='".$photo_comment_list[$n]."'
                                WHERE id_photo='".$value."' AND id_album='".$id_album."'" ,$db);

                  echo "<span class=\"text1\"><center>".
                       "".$photo_result['filename']." <b>".$photo_result['description']."</b> $TEXT020".
                       " <b>$photo_comment_list[$n]</b></center></span>";
                  // Uncoment only for debbuging
                  //echo "value-> $value, filename->$filename_list[$n]<br>";
                  $n++;
                  }
return 0;
}

function dbwa_put_comment ($id_info, $id_author, $id_comment, $posted, $title, $body_text, $text_type, $typed_secret_code){
include ("config_site.php");
include ("db_connect.php");
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
session_start();
$secret_code = $_SESSION["captcha-session"];
// if father_comment field is 0 the comment is a new comment.
// if father_comment field is != 0 then, the comment is a answer to comment.
$father_comment=$id_comment;

if ( strcasecmp ( $secret_code, $typed_secret_code) == 0 )
   {
   mysql_query ("INSERT INTO comment (id_info,id_author,father_comment,posted,title,body_text,text_type) 
                             values ('$id_info','$id_author', '$father_comment' ,'$posted', '$title','$body_text','$text_type')");
   } else echo "<div class=\"alert1b\" align=\"center\">$TEXT021</div>";

return 0;
}


function dbwa_edit_info ($id_info,$id_photo, $headline, $intro_text, $body_text, $text_type, $edited, $modified_by, $num_photos, $task, $choice){
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
include ("includes/config_site.php");
include ("includes/system_config.php");
include ("db_connect.php");

if (strlen($intro_text) > 0) { $intro='YES';} else $intro='NO';

if ($choice==$PREVIEW)
   {
   if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]) || $num_photos>=1 )
      {
      mysql_query ("UPDATE info SET modified_by='$modified_by',headline='$headline',intro_text='$intro_text',body_text='$body_text',text_type='$text_type',attached_photos='YES' ,use_intro='$intro',edited='$edited' WHERE id_info='$id_info'",$db);
      } else {
             // The default value of attached_photos is 'NO'
             mysql_query ("UPDATE info SET  modified_by='$modified_by',headline='$headline',intro_text='$intro_text',body_text='$body_text',text_type='$text_type',attached_photos='NO',use_intro='$intro',edited='$edited' WHERE id_info='$id_info'",$db);
             }
   }

if ($choice==$SAVE)
   {
   if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]) || $num_photos>=1 )
      {
      mysql_query ("UPDATE info SET modified_by='$modified_by',headline='$headline',intro_text='$intro_text',body_text='$body_text',text_type='$text_type',attached_photos='YES' ,use_intro='$intro',edited='$edited' ,status='1' WHERE id_info='$id_info'",$db);
      } else {
             // The default value of attached_photos is 'NO'
             mysql_query ("UPDATE info SET  modified_by='$modified_by',headline='$headline',intro_text='$intro_text',body_text='$body_text',text_type='$text_type',attached_photos='NO',use_intro='$intro',edited='$edited', status=1 WHERE id_info='$id_info'",$db);
             }
   }

if ($choice==$PUBLISH)
   {
   if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]) || $num_photos>=1 )
      {
      mysql_query ("UPDATE info SET modified_by='$modified_by',headline='$headline',intro_text='$intro_text',body_text='$body_text',text_type='$text_type',attached_photos='YES' ,use_intro='$intro',edited='$edited' ,status='2' WHERE id_info='$id_info'",$db);
      } else {
             // The default value of attached_photos is 'NO'
             mysql_query ("UPDATE info SET  modified_by='$modified_by',headline='$headline',intro_text='$intro_text',body_text='$body_text',text_type='$text_type',attached_photos='NO',use_intro='$intro',edited='$edited', status=2 WHERE id_info='$id_info'",$db);
             }
   include ("rss/rss_generator.php"); // Update RSS 2.0 feeds using rss_generator.php engine
   }

/*
For each info with uploaded images, a new entry in the album table should be added. 
Also the directory on where the photos and thumbnails will be saved, should be created. 
If the directory already exists, only photos and thumbnails should be added.
*/

$exist=file_exists("photos/infos/$id_info");
$is_dir=is_dir("photos/infos/$id_info");
if (!$exist || !$is_dir)mkdir("photos/infos/".$id_info,0777);
if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
   {
   $filename=$_FILES['userfile']['name'][0];
   $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
   $filename=str_replace($pattern,"_",$filename);
   $path_photo="photos/infos/$id_info/$filename";
   move_uploaded_file($_FILES['userfile']['tmp_name'][0], $path_photo);
   $size=getimagesize($path_photo);
   $width=$size[0];
   $height=$size[1];

   // Once the photo is already uploaded, the entry should be added to the album table.
   mysql_query ("INSERT INTO info_album (id_info,filename,height,width) values ('$id_info','$filename','$height','$width')");

   // If uploaded files are bigger than 200x200 pixels, then a 200x200 thumbnail should be generated.
   if ( ($height > 200) || ($width > 200)  )
      {
      system("$CONVERT_PATH -geometry 200x200 +profile \"*\" photos/infos/$id_info/$filename photos/infos/$id_info/thumbnail-$filename");
      } else copy ( "photos/infos/$id_info/$filename", "photos/infos/$id_info/thumbnail-$filename");
    }

   for ( $i = 0; $i<$num_photos; $i++) // delete selected photos
       {
       if (isset($id_photo["$i"]))
          {
          $album_query=mysql_query("SELECT filename
                                    FROM info_album
                                    WHERE id_info='$id_info' AND id_photo='".$id_photo["$i"]."'", $db);
          $file=mysql_fetch_array ($album_query);
          $photo_path="photos/infos/".$id_info."/".$file['filename'];
          $thumbnail_path="photos/infos/".$id_info."/thumbnail-".$file['filename'];
          $folder="photos/infos/".$id_info;
          echo "<span class=\"text1\"><center><br><b>".
               $file['filename']."</b> $TEXT010 " . filesize($photo_path) . " $TEXT011.<br>".
               "<b>thumbnail-".$file['filename']."</b> $TEXT010 " . filesize($thumbnail_path) . " $TEXT011.<br>";
          unlink($photo_path);
          unlink($thumbnail_path);
          if (rmdir($folder))
             {
             echo "<br><br>$TEXT012 <b>$folder</b> $TEXT013</span></center><br><br>";
             }// Only if it's empty
          $sql = "DELETE FROM info_album WHERE id_info='$id_info' AND id_photo='".$id_photo["$i"]."'";
          mysql_query($sql, $db);
          // If the erased foto is the last foto for this new, then we need to put NO attached photos in db
          $num_photos=mysql_query ("SELECT filename FROM info_album WHERE id_info='$id_info'", $db);
          if (mysql_num_rows ($num_photos)==0)
             {
             mysql_query ("UPDATE info SET attached_photos='NO' WHERE id_info='$id_info'",$db);
             }
          }
       }


if ($task=="delete_files")   // only valid for delete info section (not in a news section it has their own function)
   {                         // when only one pic is deleted, it is doing in previos if in this same function  
   echo "$TEXT014.<br>";
   $sql = "DELETE FROM info_album WHERE id_info='$id_info'";
   mysql_query($sql, $db);

   $filename="photos/infos/".$id_info;
   foreach (glob("$filename/*") as $file) // Delete all files in the current info folder and shown message about it.
           {
           echo "$file $TEXT010 " . filesize($file) . " $TEXT011.<br>";
           unlink($file);
           }

   if ($is_dir)
      {
      echo "<br><br><center>$TEXT012 $filename $TEXT013</center><br><br>";
      rmdir($filename);
      }
   }
return 0;
}


function dbwa_add_info ($id_photo, $headline, $body_text, $text_type, $posted, $id_author,$modified_by, $section, $choice){
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
include ("config_site.php");
include ("db_connect.php");
include ("includes/system_config.php");

if ($modified_by=="anonymous") {$id_author=1;}

if ($choice==$PREVIEW)
   {
   if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]) || $num_photos>=1 )
      {
      mysql_query ("INSERT INTO info (id_author,headline,body_text,text_type, attached_photos,posted,edited,modified_by,section,status) values ('$id_author','$headline','$body_text','$text_type','YES','$posted','$posted','$modified_by','$section','0')");
      } else {
             // The default value of attached_photos is 'NO'
             mysql_query ("INSERT INTO info (id_author,headline,body_text,text_type,attached_photos,posted,edited,modified_by,section,status) values ('$id_author','$headline','$body_text','$text_type','NO','$posted','$posted','$modified_by','$section','0')");
             }
   }

if ($choice==$SUBMIT_NEW)
   {
   if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]) || $num_photos>=1 )
      {
      mysql_query ("INSERT INTO info (id_author,headline,body_text,text_type,attached_photos,posted,edited,modified_by,section,status) values ('$id_author','$headline','$body_text','$text_type','YES','$posted','$posted','$modified_by','$section','1')");
      } else {
             // The default value of attached_photos is 'NO'
             mysql_query ("INSERT INTO info (id_author,headline,body_text,text_type,attached_photos,posted,edited,modified_by,section,status) values ('$id_author','$headline','$body_text','$text_type','NO','$posted','$posted','$modified_by','$section','1')");
             }
   }

$id_info=mysql_insert_id ($db);

/*
For each info with uploaded images, a new entry in the album table should be added.
Also the directory on where the photos and thumbnails will be saved, should be created.
If the directory already exists, only photos and thumbnails should be added.
*/

// return the last id_info generated in the last INSERT query
$id_info=mysql_insert_id ();
$exist=file_exists("photos/infos/$id_info");
$is_dir=is_dir("photos/infos/$id_info");
if (!$exist || !$is_dir)mkdir("photos/infos/".$id_info,0777);
if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
   {
   $filename=$_FILES['userfile']['name'][0];
   $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
   $filename=str_replace($pattern,"_",$filename);
   $path_photo="photos/infos/$id_info/$filename";
   move_uploaded_file($_FILES['userfile']['tmp_name'][0], $path_photo);
   $size=getimagesize($path_photo);
   $width=$size[0];
   $height=$size[1];

   // Once the photo is already uploaded, the entry should be added to the album table.
   mysql_query ("INSERT INTO info_album (id_info,filename,height,width) values ('$id_info','$filename','$height','$width')");

   // If uploaded files are bigger than 200x200 pixels, then a 200x200 thumbnail should be generated.
   if ( ($height > 200) || ($width > 200)  )
      {
      system("$CONVERT_PATH -geometry 200x200 +profile \"*\" photos/infos/$id_info/$filename photos/infos/$id_info/thumbnail-$filename"); 
      } else copy ( "photos/infos/$id_info/$filename", "photos/infos/$id_info/thumbnail-$filename");
    }
if ($choice==$SUBMIT)
   {
   echo "<span class=\"text1\"><center><br><br>$TEXT015</center><br><br>";
   }
return $id_info;
}

function dbwa_delete_info ($id_info){
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
include ("config_site.php");
include ("db_connect.php");
$sql = "DELETE FROM info WHERE id_info='$id_info'";
mysql_query($sql, $db);
$sql = "DELETE FROM info_album WHERE id_info='$id_info'";
mysql_query($sql, $db);
$sql = "DELETE FROM comment WHERE id_info='$id_info'";
mysql_query($sql, $db);
$is_dir=is_dir("photos/infos/$id_info");
$filename="photos/infos/".$id_info;
echo "<br>";
foreach (glob("$filename/*") as $file) // Delete all files in the current info folder and shown message about it.
        {
        echo "<span class=\"text1\"><center><b>$file</b> $TEXT010 " . filesize($file) . " $TEXT011.</center></span>";
        unlink($file);
        }

if ($is_dir)
   {
   echo "<span class=\"text1\"><center><br><br>$TEXT012 <b>$filename</b> $TEXT013</center><br><br>";
   rmdir($filename);
   }

include ("rss/rss_generator.php"); // Update RSS 2.0 feeds using rss_generator.php engine

return 0;
}

function dbwa_add_user ($new_nick, $password, $password_check, $email, $real_name, $level) {
include ("config_site.php");
include ("db_connect.php");
include ("includes/system_config.php");

$check_nickname=mysql_query("SELECT nick FROM users WHERE nick='$new_nick'", $db);
$n=mysql_num_rows ($check_nickname);

$user_form=check_user_form ($new_nick, $password, $password_check, $n);

if ( $user_form == 0 ) // check if nickname is unused and password is correct
   {
   if (is_uploaded_file($_FILES['user_photo']['tmp_name'][0]))
     {
     mysql_query ("INSERT INTO users (nick, password, email, real_name, level) values ('$new_nick','$password','$email','$real_name','$level')",$db);
     // The following line returns the field autoincrement generated
     // in the lasst INSTERT sentence
     $id_user=mysql_insert_id ();
     $filename=$_FILES['user_photo']['name'][0];
     $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
     $filename=str_replace($pattern,"_",$filename);
     $path_photo="photos/users/$id_user/$filename";
     // Now that we know el ID we can update the path to the user photo directory
     mysql_query ("UPDATE users SET user_photo_file='$path_photo' WHERE id_user='$id_user'",$db);
     } else {
            // The default value of attached_photos is 'NO'
            mysql_query ("INSERT INTO users (nick, password, email, real_name,level) values ('$new_nick','$password','$email','$real_name','$level')",$db);
            }

/*
For each info with uploaded images, a new entry in the album table should be added.
Also the directory on where the photos and thumbnails will be saved, should be created.
If the directory already exists, only photos and thumbnails should be added.
*/

  $exist=file_exists("photos/users/$id_user");
  $is_dir=is_dir("photos/users/$id_user");
  if (!$exist || !$is_dir)mkdir("photos/users/".$id_user,0777);
  if (is_uploaded_file($_FILES['user_photo']['tmp_name'][0]))
     { 
     $filename=$_FILES['user_photo']['name'][0];
     $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
     $filename=str_replace($pattern,"_",$filename);
     $path_user_photo="photos/users/$id_user/$filename";
     move_uploaded_file($_FILES['user_photo']['tmp_name'][0], $path_user_photo);
     $size=getimagesize($path_user_photo);
     $width=$size[0];
     $height=$size[1];
     
     // If uploaded file is bigger than 70x100 pixels an small image is generated
     if ( ($height > 100) || ($width > 70)  )
        {
        system("$CONVERT_PATH -geometry 70x100 +profile \"*\" $path_user_photo $path_user_photo");
        } else copy ( "$filename", "$filename");
     }
  }
return 0;
}

function dbwa_add_unprivileged_user ($new_nick, $password, $password_check, $email, $real_name) {
global $LANGUAGE;
include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
include ("config_site.php");
include ("db_connect.php");
include ("includes/system_config.php");

$check_nickname=mysql_query("SELECT nick FROM users WHERE nick='$new_nick'", $db);
$n=mysql_num_rows ($check_nickname);

$user_form=check_user_form ($new_nick, $password, $password_check, $n);

if ( $user_form == 0 ) // check if nickname is unused and password is correct
   {
   if (is_uploaded_file($_FILES['user_photo']['tmp_name'][0]))
     {
     mysql_query ("INSERT INTO users (nick, password, email, real_name) values ('$new_nick','$password','$email','$real_name')",$db);
     // The following line returns the field autoincrement generated 
     // in the lasst INSTERT sentence
     $id_user=mysql_insert_id ();
     $filename=$_FILES['user_photo']['name'][0];
     $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
     $filename=str_replace($pattern,"_",$filename);
     $path_photo="photos/users/$id_user/$filename";
     // Now that we know el ID we can update the path to the user photo directory
     mysql_query ("UPDATE users SET user_photo_file='$path_photo' WHERE id_user='$id_user'",$db);
     } else {
            // The default value of attached_photos is 'NO'
            mysql_query ("INSERT INTO users (nick, password, email, real_name) values ('$new_nick','$password','$email','$real_name')",$db);
            }
  echo "<div class=\"title1-blue\" align=\"center\">$TEXT016</div>";

/*
For each info with uploaded images, a new entry in the album table should be added.
Also the directory on where the photos and thumbnails will be saved, should be created.
If the directory already exists, only photos and thumbnails should be added.
*/

  $exist=file_exists("photos/users/$id_user");
  $is_dir=is_dir("photos/users/$id_user");
  if (!$exist || !$is_dir)mkdir("photos/users/".$id_user,0777);
  if (is_uploaded_file($_FILES['user_photo']['tmp_name'][0]))
     {
     $filename=$_FILES['user_photo']['name'][0];
     $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
     $filename=str_replace($pattern,"_",$filename);
     $path_user_photo="photos/users/$id_user/$filename";
     move_uploaded_file($_FILES['user_photo']['tmp_name'][0], $path_user_photo);
     $size=getimagesize($path_user_photo);
     $width=$size[0];
     $height=$size[1];

     // If uploaded file is bigger than 70x100 pixels, then an small image is generated
     if ( ($height > 100) || ($width > 70)  )
        {
        system("$CONVERT_PATH -geometry 70x100 +profile \"*\" $path_user_photo $path_user_photo");
        } else copy ( "$filename", "$filename");
     }
  }
return 0;
}


function dbwa_edit_user ($id_user, $new_nick, $password, $password_check, $real_name, $email, $level) {
include ("config_site.php");
include ("db_connect.php");
include ("includes/system_config.php");

$check_nickname=mysql_query("SELECT nick, password FROM users WHERE nick='$new_nick' AND id_user!='$id_user'", $db);
$n=mysql_num_rows ($check_nickname);
$query_md5=mysql_query("SELECT password FROM users WHERE id_user='$id_user'", $db);
$md5=mysql_fetch_array($query_md5);
$second_md5=crypt($md5['password'],'zzxzv');
$user_form=check_user_form ($new_nick, $password, $password_check, $n);

if ( $user_form == 0 ) // check if nickname is unused and password is correct
   {
   if (is_uploaded_file($_FILES['user_photo']['tmp_name'][0]))
      {
      if ($password==$second_md5)
         {
      mysql_query ("UPDATE users SET nick='$new_nick', email='$email', real_name='$real_name', level='$level' WHERE id_user='$id_user'",$db);
         } else mysql_query ("UPDATE users SET nick='$new_nick', password='$password', email='$email', real_name='$real_name', level='$level' WHERE id_user='$id_user'",$db);

      $filename=$_FILES['user_photo']['name'][0];
      $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
      $filename=str_replace($pattern,"_",$filename);
      $path_photo="photos/users/$id_user/$filename";
      mysql_query ("UPDATE users SET user_photo_file='$path_photo' WHERE id_user='$id_user'",$db);
      } else {
             // The default value of attached_photos is 'NO'
             if ($password==$second_md5)
                {
                mysql_query ("UPDATE users SET nick='$new_nick', email='$email', real_name='$real_name', level='$level' WHERE id_user='$id_user'",$db);
                } else mysql_query ("UPDATE users SET nick='$new_nick', password='$password', email='$email', real_name='$real_name', level='$level' WHERE id_user='$id_user'",$db);

            }

  $exist=file_exists("photos/users/$id_user");
  $is_dir=is_dir("photos/users/$id_user");
  if (!$exist || !$is_dir) mkdir("photos/users/".$id_user,0777);
  if (is_uploaded_file($_FILES['user_photo']['tmp_name'][0]))
     {
     system ("rm photos/users/".$id_user."/*");
     $filename=$_FILES['user_photo']['name'][0];
     $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
     $filename=str_replace($pattern,"_",$filename);
     $path_user_photo="photos/users/$id_user/$filename";
     move_uploaded_file($_FILES['user_photo']['tmp_name'][0], $path_user_photo);
     $size=getimagesize($path_user_photo);
     $width=$size[0];
     $height=$size[1];

     // If the uploaded file is bigger than 70x100 pixels, then generate a 70x100 image
     if ( ($height > 100) || ($width > 70)  )
        {
        system("$CONVERT_PATH -geometry 70x100 +profile \"*\" $path_user_photo $path_user_photo");
        } else copy ( "$filename", "$filename");
     }
  }
return 0;
}



function dbwa_delete_user ($id_user){
include ("config_site.php");
include ("db_connect.php");

$query=mysql_query("SELECT user_photo_file FROM users WHERE id_user='".$id_user."'", $db);
$result_query=mysql_fetch_array ($query);
$path_to_file=$result_query["user_photo_file"];
$path_to_photo_dir="photos/users/".$id_user.";
echo $path_to_file;

echo $path_to_photo_dir";

if ($path_to_file != "photos/users/anonymous.jpg")
   {
   unlink ($path_to_file);
   rmdir ("photos/users/$id_user");
   }
// The user is deleted from the users table
$sql = "DELETE FROM users WHERE id_user='$id_user'";
mysql_query($sql, $db);

return 0;
}



function dbwa_diary ($top_tab, $section_type, $event_title, $event_type, $event_place, $description, $day, $year, $month, $hour, $minutes ){
include ("config_site.php");
include ("db_connect.php");

$section="TAB_".$top_tab.$section_type;
$event_date="".$year."-".$month."-".$day." ".$hour.":".$minutes.":00";

mysql_query ("INSERT INTO diary (section,event_title,event_type,event_place,description,event_date) values ('$section', '$event_title','$event_type','$event_place','$description','$event_date')");

return 0;
}


include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");

// Frist, DBWA check if others script has been send a request for this services
if(isset($dbwa) && $dbwa!="NULL") 
  {
  // After that, DBWA checks for the correct authentication of the request
  if (isset($_GET['num'])) {$num=$_GET['num'];} else {$num="";}
  if (isset($_COOKIE["id_session"]))
    {
    $id_session=$_COOKIE["id_session"];
    } else {
           $id_session="NULL";
           }


  if ($num==$id_session['num'])
    {
    // Then, DWBA process the request propertly
    //Call to the properly dbwa function (specificated when dbwa scriptis called)
    if ($dbwa=="dbwa_edit_info") $dbwa ($id_info,$id_photo, $headline, $intro_text, $body_text, $text_type, $edited, $id_session['user'],$num_photos, $task, $choice);
    if ($dbwa=="dbwa_add_info") $id_info=$dbwa ($id_photo, $headline, $body_text, $text_type, $posted, $id_session['id_user'],$id_session['user'],"TAB_$top_tab$section_type",$choice); 
    if ($dbwa=="dbwa_delete_info") $dbwa ($id_info);
    if ($dbwa=="dbwa_edit_user") $dbwa ($id_user, $new_nick, $password, $password_check, $real_name, $email, $level);
    if ($dbwa=="dbwa_add_user") $dbwa ($new_nick, $password, $password_check, $email, $real_name, $level);
    if ($dbwa=="dbwa_delete_user") $dbwa ($id_user);
    if ($dbwa=="dbwa_diary") $dbwa ($top_tab, $section_type, $event_title, $event_type, $event_place, $description, $day, $year, $month, $hour, $minutes); 
    if ($dbwa=="dbwa_put_comment") $dbwa ($id_info, $id_session['id_user'], $id_comment, $posted, $title, $body_text,$text_type,$typed_secret_code);
    if ($dbwa=="dbwa_add_album") $valid_album_form=$dbwa ($title, $description, $posted, $id_session['id_user'],"TAB_$top_tab$section_type",$allow_to_see, $allow_to_add, $allow_to_see_list, $allow_to_add_list); 
    if ($dbwa=="dbwa_edit_album") $dbwa ($id_album, $title, $description, $posted, "TAB_$top_tab$section_type",$allow_to_see, $allow_to_add, $allow_to_see_list, $allow_to_add_list); 
    if ($dbwa=="dbwa_add_photo_album") $dbwa ($id_album,$id_session['id_user'], $description,$posted);
    if ($dbwa=="dbwa_delete_photo_album") $dbwa ($id_album,$id_photo_list,$filename_list);//delete all the photos and data album
    if ($dbwa=="dbwa_edit_photo_comments") $dbwa ($id_album,$id_photo_list,$photo_comment_list);//edit all the photo comments
    echo "<div class=\"text1\" align=\"center\">$TEXT017. </div>";
    } else if ($dbwa=="dbwa_add_unprivileged_user" || $dbwa=="dbwa_put_comment" || $dbwa=="dbwa_add_info" || $dbwa=="dbwa_edit_info" || $dbwa=="dbwa_add_photo_album")
              {
              if ($dbwa=="dbwa_add_unprivileged_user") $dbwa ($new_nick, $password, $password_check, $email, $real_name);
              if ($dbwa=="dbwa_put_comment") $dbwa ($id_info, 0, $id_comment, $posted, $title, $body_text,$text_type,$typed_secret_code);
              if ($dbwa=="dbwa_edit_info") $dbwa ($id_info,$id_photo, $headline, $body_text, $text_type, $edited,'anonymous',$num_photos, $task, $choice);
              if ($dbwa=="dbwa_add_info") $id_info=$dbwa ($id_photo, $headline, $body_text, $text_type, $posted, 0,'anonymous',"TAB_$top_tab$section_type",$choice); 
             if ($dbwa=="dbwa_add_photo_album") $dbwa ($id_album,$id_session['id_user'], $description,$posted);
              echo "<div class=\"text1\" align=\"center\">$TEXT017. </div>";
              }else {
                    // Report error authentication to the invalid user
                    echo "<div class=\"text1\">$TEXT018</div>";
                    }
  }

?>
